@@ -37,14 +37,15 @@ pub mod evaluation;
 pub mod event_logging;
 pub mod global_configs;
 pub mod hashing;
-pub mod hashset_with_ttl;
 pub mod instance_registry;
 pub mod networking;
 pub mod output_logger;
 pub mod override_adapter;
 pub mod sdk_diagnostics;
+pub mod sdk_event_emitter;
 pub mod specs_response;
 pub mod statsig_core_api_options;
+pub mod statsig_global;
 pub mod statsig_metadata;
 pub mod statsig_options;
 pub mod statsig_types;
